@@ -22,7 +22,6 @@ class Config:
     use_quote_protection: bool
 
     api_key: str
-    is_pro_version: bool
 
     # Advanced options.
     tl_max_chunks: int
@@ -35,6 +34,7 @@ class Config:
     epub_nuke_indents: bool
     epub_crush: bool
     epub_make_text_horizontal: bool
+    epub_ignore_empty_html: bool
     # Timing history.
     avg_time_per_mille: float
 
@@ -158,17 +158,17 @@ def default_config() -> Config:
         use_glossary=True,
         use_quote_protection=True,
         api_key="",
-        is_pro_version=False,
         tl_max_chunks=20,
         tl_min_chunk_size=10_000,
         tl_preserve_formatting=True,
         tl_mock=False,
-        dump_on_abort=False,
+        dump_on_abort=True,
         epub_nuke_kobo=True,
         epub_nuke_ruby=True,
         epub_nuke_indents=True,
         epub_make_text_horizontal=True,
         epub_crush=False,  # This could confuse deepl and subsequent epub readers too much.
+        epub_ignore_empty_html=True,
         avg_time_per_mille=0.33,  # This was measured experimentally. Depends on local internet connection.
     )
 
