@@ -311,6 +311,7 @@ class FileTable(CTableWidget):
             nuke_indents=self.config.epub_nuke_indents,
             crush_html=self.config.epub_crush,
             make_text_horizontal=self.config.epub_make_text_horizontal,
+            ignore_empty=self.config.epub_ignore_empty_html,
         )
 
         if apply_glossary:
@@ -334,6 +335,7 @@ class FileTable(CTableWidget):
         """
         Update the table with the result of the glossary processing.
         """
+        logger.debug(f"Worker thread {file_id} finished.")
         # Ignore if the file no longer exists.
         if file_id not in self.files:
             logger.info(f"File {file_id} no longer exists, ignoring result.")
@@ -517,7 +519,10 @@ def make_output_filename(input_file: st.InputFile, config: cfg.Config) -> Path:
         path = path.with_suffix(".DUMP")
 
     if config.use_fixed_output_path:
-        path = Path(config.fixed_output_path) / path.name
+        # Make the fixed output path absolute, meaning it isn't relative to the
+        # current working directory.
+        path = Path("/") / config.fixed_output_path / path.name
+        path = path.resolve()
 
     path = hp.ensure_unique_file_path(path)
 
